@@ -2,7 +2,8 @@ from typing import Dict
 
 from ccxt import Exchange
 from pandas import DataFrame
-from quick_trade import utils
+
+from . import utils
 
 
 class TradingClient(object):
