@@ -1,4 +1,7 @@
-from typing import Iterable, Dict, Any, List
+from typing import Any
+from typing import Dict
+from typing import Iterable
+from typing import List
 
 
 def transform_tunable_param(param_and_value: Dict[str, Any]):
@@ -36,3 +39,6 @@ def transform_all_tunable_values(strategies_kwargs: Dict[str, List[Dict[str, Any
 
 class TunableValue(object):
     values: Iterable[Any]
+
+    def __init__(self, values: Iterable[Any]):
+        self.values = values
