@@ -6,7 +6,6 @@
 #   scalper and dca bot
 #   more docs and examples
 #   decimal
-#   multi-backtest normal calculating(real multi-test, not sum of single tests)
 #   add meta-data in tuner's returns
 #   add "tradingview backtest"
 
@@ -29,7 +28,7 @@ from warnings import warn
 import ta.momentum
 import ta.trend
 import ta.volatility
-from numpy import array
+from math import prod
 from numpy import digitize
 from numpy import inf
 from numpy import mean
@@ -361,6 +360,7 @@ class Trader(object):
                 no_order = False
                 exit_take_stop = False
                 ignore_breakout = True
+
                 if sig != utils.EXIT and not min(stop_loss, take_profit) <= open_price <= max(stop_loss, take_profit) and e > 0:
                     warn('The deal was opened out of range!')
                     utils.logger.error('The deal was opened out of range!')
@@ -372,50 +372,53 @@ class Trader(object):
                     pass_math = True
                     break
 
-            next_not_breakout = min(stop_loss, take_profit) < next_l <= next_h < max(stop_loss, take_profit)
+            if sig != utils.EXIT:
+                next_not_breakout = min(stop_loss, take_profit) < next_l <= next_h < max(stop_loss, take_profit)
 
-            stop_loss = self._stop_losses[e - 1]
-            take_profit = self._take_profits[e - 1]
-            # be careful with e=0
-            # haha))) no)
-            now_not_breakout = min(stop_loss, take_profit) < low <= high < max(stop_loss, take_profit)
-            normal = (ignore_breakout or now_not_breakout) and next_not_breakout
-            if credit_lev != self._credit_leverages[e - 1] and not ignore_breakout:
-                deposit -= bet * (commission / 100) * abs(self._credit_leverages[e - 1] - credit_lev)
-                # Commission when changing the leverage.
-                if bet > deposit:
-                    bet = deposit
-            if normal:
-                diff = data_column[e + 1] - data_column[e]
+                stop_loss = self._stop_losses[e - 1]
+                take_profit = self._take_profits[e - 1]
+                # be careful with e=0
+                # haha))) no)
+                now_not_breakout = min(stop_loss, take_profit) < low <= high < max(stop_loss, take_profit)
+
+                normal = (ignore_breakout or now_not_breakout) and next_not_breakout
+
+                if credit_lev != self._credit_leverages[e - 1] and not ignore_breakout:
+                    deposit -= bet * (commission / 100) * abs(self._credit_leverages[e - 1] - credit_lev)
+                    # Commission when changing the leverage.
+                    if bet > deposit:
+                        bet = deposit
+                if normal:
+                    diff = data_column[e + 1] - data_column[e]
+                else:
+                    # Here I am using the previous value,
+                    # because we do not know the value at this point
+                    # (it is generated only when the candle is closed).
+                    exit_take_stop = True
+
+                    if (not now_not_breakout) and not ignore_breakout:
+                        stop_loss = self._stop_losses[e - 1]
+                        take_profit = self._take_profits[e - 1]
+                        diff = utils.get_diff(price=data_column[e],
+                                              low=low,
+                                              high=high,
+                                              stop_loss=stop_loss,
+                                              take_profit=take_profit,
+                                              signal=sig)
+
+                    elif not next_not_breakout:
+                        stop_loss = self._stop_losses[e]
+                        take_profit = self._take_profits[e]
+                        diff = utils.get_diff(price=data_column[e],
+                                              low=next_l,
+                                              high=next_h,
+                                              stop_loss=stop_loss,
+                                              take_profit=take_profit,
+                                              signal=sig)
             else:
-                # Here I am using the previous value,
-                # because we do not know the value at this point
-                # (it is generated only when the candle is closed).
-                exit_take_stop = True
-
-                if (not now_not_breakout) and not ignore_breakout:
-                    stop_loss = self._stop_losses[e - 1]
-                    take_profit = self._take_profits[e - 1]
-                    diff = utils.get_diff(price=data_column[e],
-                                          low=low,
-                                          high=high,
-                                          stop_loss=stop_loss,
-                                          take_profit=take_profit,
-                                          signal=sig)
-
-                elif not next_not_breakout:
-                    stop_loss = self._stop_losses[e]
-                    take_profit = self._take_profits[e]
-                    diff = utils.get_diff(price=data_column[e],
-                                          low=next_l,
-                                          high=next_h,
-                                          stop_loss=stop_loss,
-                                          take_profit=take_profit,
-                                          signal=sig)
+                diff = 0.0
             if sig == utils.SELL:
                 diff = -diff
-            if sig == utils.EXIT:
-                diff = 0.0
 
             if not no_order:
                 deposit += bet * credit_lev * diff / open_price
@@ -501,8 +504,9 @@ class Trader(object):
         losses: List[int] = []
         trades: List[int] = []
         profits: List[int] = []
-        depo: List[ndarray] = []
+        depos: List[Series] = []
         lens_dep: List[int] = []
+        self.deposit_history = []
 
         for ticker in tickers:
             df = self.client.get_data_historical(ticker=ticker, limit=limit, interval=self.interval)
@@ -524,7 +528,7 @@ class Trader(object):
             losses.append(new_trader.losses)
             trades.append(new_trader.trades)
             profits.append(new_trader.profits)
-            depo.append(array(new_trader.deposit_history))
+            depos.append(Series(new_trader.deposit_history))
             lens_dep.append(len(new_trader.deposit_history))
         self.losses = sum(losses)
         self.trades = sum(profits)
@@ -532,10 +536,14 @@ class Trader(object):
         self.year_profit = float(mean(percentage_profits))
         self.winrate = float(mean(winrates))
 
-        for enum, elem in enumerate(depo):
-            depo[enum] = array(elem[-min(lens_dep):]) / (elem[-min(lens_dep)] / (deposit / len(tickers)))
-        self.deposit_history = list(sum(depo))
+        for enum, elem in enumerate(depos):
+            depos[enum] = utils.get_multipliers(Series(elem[-min(lens_dep):]))
 
+        multipliers: Series = prod(depos)
+        deposit_elem: float = deposit
+        for multiplier in multipliers.values:
+            deposit_elem *= multiplier
+            self.deposit_history.append(deposit_elem)
         self.average_growth = utils.get_exponential_growth(self.deposit_history)
         self.returns_strategy_diff = list(Series(self.deposit_history).diff().values)
         self.returns_strategy_diff[0] = 0
